@@ -3,15 +3,15 @@ use strict;
 use warnings;
 use Moo::Role;
 use Carp qw(croak);
-use feature qw( current_sub);
 with 'Archive::BagIt::Role::Plugin';
 # ABSTRACT: A role that defines the interface to a hashing algorithm
-our $VERSION = '0.085'; # VERSION
+our $VERSION = '0.086'; # VERSION
 
 has 'name' => (
     is => 'ro',
 );
 
+
 sub get_optimal_bufsize {
     my ($self, $fh) = @_;
     my ($dev,$ino,$mode,$nlink,$uid,$gid,$rdev,$size,
@@ -47,7 +47,11 @@ Archive::BagIt::Role::Algorithm - A role that defines the interface to a hashing
 
 =head1 VERSION
 
-version 0.085
+version 0.086
+
+=head2 get_optimal_bufsize($fh)
+
+uses L<stat> to determine optimal filesize, defaults to 8192
 
 =head1 AVAILABILITY
 
