@@ -2,10 +2,10 @@ package Archive::BagIt::Role::Plugin;
 use strict;
 use warnings;
 use Moo::Role;
-use IO::Async::Loop;
+
 use namespace::autoclean;
 # ABSTRACT: A role that handles plugin loading
-our $VERSION = '0.085'; # VERSION
+our $VERSION = '0.086'; # VERSION
 
 has plugin_name => (
   is  => 'ro',
@@ -13,12 +13,6 @@ has plugin_name => (
   default => __PACKAGE__,
 );
 
-has '_ioloop' => (
-    is      => 'ro',
-    default => sub {
-        IO::Async::Loop->new();
-    }
-);
 
 has bagit => (
   is  => 'ro',
@@ -48,7 +42,11 @@ Archive::BagIt::Role::Plugin - A role that handles plugin loading
 
 =head1 VERSION
 
-version 0.085
+version 0.086
+
+=head2 bagit()
+
+holds the current bag object as weak reference
 
 =head1 AVAILABILITY
 
